==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/layout/editor/buddy/gui/BuddyGuiButton.java <==
package de.keksuccino.fancymenu.customization.layout.editor.buddy.gui;

import de.keksuccino.fancymenu.customization.layout.editor.buddy.Buddy;
import de.keksuccino.fancymenu.util.rendering.gui.GuiGraphics;
import de.keksuccino.fancymenu.util.rendering.gui.Renderable;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import java.util.function.BooleanSupplier;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_327;

/**
 * Represents a button in the buddy GUI
 */
public class BuddyGuiButton implements Renderable {

    public static final class_2960 DEFAULT_BUTTON_NORMAL = new class_2960("fancymenu", "textures/buddy/gui/default_button_normal.png");
    public static final class_2960 DEFAULT_BUTTON_HOVER = new class_2960("fancymenu", "textures/buddy/gui/default_button_hover.png");
    public static final class_2960 DEFAULT_BUTTON_INACTIVE = new class_2960("fancymenu", "textures/buddy/gui/default_button_inactive.png");
    public static final class_2960 BUTTON_CLOSE_NORMAL = new class_2960("fancymenu", "textures/buddy/gui/button_close_normal.png");
    public static final class_2960 BUTTON_CLOSE_HOVER = new class_2960("fancymenu", "textures/buddy/gui/button_close_hover.png");

    private static final int DEFAULT_BUTTON_WIDTH = 80;
    private static final int DEFAULT_BUTTON_HEIGHT = 20;

    @NotNull
    protected final ButtonNameSupplier nameSupplier;
    @NotNull
    protected final Runnable action;
    @Nullable
    protected final BooleanSupplier activeCondition;
    @NotNull
    protected final Buddy buddy;
    protected int x;
    protected int y;
    protected int width;
    protected int height;
    protected boolean active = true;
    @Nullable
    protected class_2960 normalTexture = null;
    @Nullable
    protected class_2960 hoverTexture = null;
    @Nullable
    protected class_2960 inactiveTexture = null;

    public BuddyGuiButton(@NotNull Buddy buddy, int x, int y, int width, int height, @NotNull ButtonNameSupplier nameSupplier, @NotNull Runnable action, @Nullable BooleanSupplier activeCondition) {
        this.nameSupplier = nameSupplier;
        this.action = action;
        this.activeCondition = activeCondition;
        this.buddy = buddy;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.setDefaultButtonTextures();
    }

    public BuddyGuiButton(@NotNull Buddy buddy, int x, int y, @NotNull ButtonNameSupplier nameSupplier, @NotNull Runnable action, @Nullable BooleanSupplier activeCondition) {
        this(buddy, x, y, DEFAULT_BUTTON_WIDTH, DEFAULT_BUTTON_HEIGHT, nameSupplier, action, activeCondition);
    }

    public BuddyGuiButton(@NotNull Buddy buddy, @NotNull ButtonNameSupplier nameSupplier, @NotNull Runnable action, @Nullable BooleanSupplier activeCondition) {
        this(buddy, 0, 0, DEFAULT_BUTTON_WIDTH, DEFAULT_BUTTON_HEIGHT, nameSupplier, action, activeCondition);
    }

    @Override
    public void render(GuiGraphics graphics, int mouseX, int mouseY, float partial) {
        boolean hovered = isMouseOver(mouseX, mouseY) && active;
        class_2960 backgroundTexture = active ? (hovered ? this.hoverTexture : this.normalTexture) : this.inactiveTexture;
        int backgroundColor = active ? (hovered ? 0xFF909090 : 0xFF606060) : 0xFF404040;
        int textColor = active ? 0xFFFFFFFF : 0xFFAAAAAA;
        class_327 font = class_310.method_1551().field_1772;

        // Draw button background
        if (backgroundTexture != null) {
            graphics.blit(backgroundTexture, this.x, this.y, 0.0F, 0.0F, this.width, this.height, this.width, this.height);
        } else {
            graphics.fill(x, y, x + this.width, y + this.height, backgroundColor);
            graphics.renderOutline(x, y, this.width, this.height, 0xFF000000);
        }

        // Draw button text
        String name = nameSupplier.name(this.buddy);
        int textX = x + (this.width - font.method_1727(name)) / 2;
        int textY = y + (this.height - 8) / 2;
        graphics.drawString(font, name, textX, textY, textColor);
    }

    public void onClick() {
        if (active) {
            action.run();
        }
    }

    public BuddyGuiButton setTextures(@Nullable class_2960 normal, @Nullable class_2960 hover, @Nullable class_2960 inactive) {
        this.normalTexture = normal;
        this.hoverTexture = hover;
        this.inactiveTexture = inactive;
        return this;
    }

    public BuddyGuiButton setDefaultButtonTextures() {
        return this.setTextures(DEFAULT_BUTTON_NORMAL, DEFAULT_BUTTON_HOVER, DEFAULT_BUTTON_INACTIVE);
    }

    public BuddyGuiButton setCloseButtonTextures() {
        return this.setTextures(BUTTON_CLOSE_NORMAL, BUTTON_CLOSE_HOVER, BUTTON_CLOSE_NORMAL);
    }

    public BuddyGuiButton setPosition(int x, int y) {
        this.x = x;
        this.y = y;
        return this;
    }

    public BuddyGuiButton setSize(int width, int height) {
        this.width = width;
        this.height = height;
        return this;
    }

    public int getX() {
        return x;
    }

    public BuddyGuiButton setX(int x) {
        this.x = x;
        return this;
    }

    public int getY() {
        return y;
    }

    public BuddyGuiButton setY(int y) {
        this.y = y;
        return this;
    }

    public int getWidth() {
        return width;
    }

    public BuddyGuiButton setWidth(int width) {
        this.width = width;
        return this;
    }

    public int getHeight() {
        return height;
    }

    public BuddyGuiButton setHeight(int height) {
        this.height = height;
        return this;
    }

    public boolean isMouseOver(double mouseX, double mouseY) {
        return mouseX >= x && mouseX < x + this.width && mouseY >= y && mouseY < y + this.height;
    }

    public boolean isActive() {
        return active;
    }

    public void updateActiveState() {
        this.active = activeCondition == null || activeCondition.getAsBoolean();
    }

    @FunctionalInterface
    public interface ButtonNameSupplier {
        String name(@NotNull Buddy buddy);
    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/layout/editor/buddy/gui/BuddyGuiButton.java <==
package de.keksuccino.fancymenu.customization.layout.editor.buddy.gui;

import de.keksuccino.fancymenu.customization.layout.editor.buddy.Buddy;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.function.BooleanSupplier;
import net.minecraft.class_10799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_4068;

/**
 * Represents a button in the buddy GUI
 */
public class BuddyGuiButton implements class_4068 {

    public static final class_2960 DEFAULT_BUTTON_NORMAL = class_2960.method_60655("fancymenu", "textures/buddy/gui/default_button_normal.png");
    public static final class_2960 DEFAULT_BUTTON_HOVER = class_2960.method_60655("fancymenu", "textures/buddy/gui/default_button_hover.png");
    public static final class_2960 DEFAULT_BUTTON_INACTIVE = class_2960.method_60655("fancymenu", "textures/buddy/gui/default_button_inactive.png");
    public static final class_2960 BUTTON_CLOSE_NORMAL = class_2960.method_60655("fancymenu", "textures/buddy/gui/button_close_normal.png");
    public static final class_2960 BUTTON_CLOSE_HOVER = class_2960.method_60655("fancymenu", "textures/buddy/gui/button_close_hover.png");

    private static final int DEFAULT_BUTTON_WIDTH = 80;
    private static final int DEFAULT_BUTTON_HEIGHT = 20;

    @NotNull
    protected final ButtonNameSupplier nameSupplier;
    @NotNull
    protected final Runnable action;
    @Nullable
    protected final BooleanSupplier activeCondition;
    @NotNull
    protected final Buddy buddy;
    protected int x;
    protected int y;
    protected int width;
    protected int height;
    protected boolean active = true;
    @Nullable
    protected class_2960 normalTexture = null;
    @Nullable
    protected class_2960 hoverTexture = null;
    @Nullable
    protected class_2960 inactiveTexture = null;

    public BuddyGuiButton(@NotNull Buddy buddy, int x, int y, int width, int height, @NotNull ButtonNameSupplier nameSupplier, @NotNull Runnable action, @Nullable BooleanSupplier activeCondition) {
        this.nameSupplier = nameSupplier;
        this.action = action;
        this.activeCondition = activeCondition;
        this.buddy = buddy;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.setDefaultButtonTextures();
    }

    public BuddyGuiButton(@NotNull Buddy buddy, int x, int y, @NotNull ButtonNameSupplier nameSupplier, @NotNull Runnable action, @Nullable BooleanSupplier activeCondition) {
        this(buddy, x, y, DEFAULT_BUTTON_WIDTH, DEFAULT_BUTTON_HEIGHT, nameSupplier, action, activeCondition);
    }

    public BuddyGuiButton(@NotNull Buddy buddy, @NotNull ButtonNameSupplier nameSupplier, @NotNull Runnable action, @Nullable BooleanSupplier activeCondition) {
        this(buddy, 0, 0, DEFAULT_BUTTON_WIDTH, DEFAULT_BUTTON_HEIGHT, nameSupplier, action, activeCondition);
    }

    @Override
    public void method_25394(class_332 graphics, int mouseX, int mouseY, float partial) {
        boolean hovered = isMouseOver(mouseX, mouseY) && active;
        class_2960 backgroundTexture = active ? (hovered ? this.hoverTexture : this.normalTexture) : this.inactiveTexture;
        int backgroundColor = active ? (hovered ? 0xFF909090 : 0xFF606060) : 0xFF404040;
        int textColor = active ? 0xFFFFFFFF : 0xFFAAAAAA;
        class_327 font = class_310.method_1551().field_1772;

        // Draw button background
        if (backgroundTexture != null) {
            graphics.method_25290(class_10799.field_56883, backgroundTexture, this.x, this.y, 0.0F, 0.0F, this.width, this.height, this.width, this.height);
        } else {
            graphics.method_25294(x, y, x + this.width, y + this.height, backgroundColor);
            graphics.method_73198(x, y, this.width, this.height, 0xFF000000);
        }

        // Draw button text
        String name = nameSupplier.name(this.buddy);
        int textX = x + (this.width - font.method_1727(name)) / 2;
        int textY = y + (this.height - 8) / 2;
        graphics.method_25303(font, name, textX, textY, textColor);
    }

    public void onClick() {
        if (active) {
            action.run();
        }
    }

    public BuddyGuiButton setTextures(@Nullable class_2960 normal, @Nullable class_2960 hover, @Nullable class_2960 inactive) {
        this.normalTexture = normal;
        this.hoverTexture = hover;
        this.inactiveTexture = inactive;
        return this;
    }

    public BuddyGuiButton setDefaultButtonTextures() {
        return this.setTextures(DEFAULT_BUTTON_NORMAL, DEFAULT_BUTTON_HOVER, DEFAULT_BUTTON_INACTIVE);
    }

    public BuddyGuiButton setCloseButtonTextures() {
        return this.setTextures(BUTTON_CLOSE_NORMAL, BUTTON_CLOSE_HOVER, BUTTON_CLOSE_NORMAL);
    }

    public BuddyGuiButton setPosition(int x, int y) {
        this.x = x;
        this.y = y;
        return this;
    }

    public BuddyGuiButton setSize(int width, int height) {
        this.width = width;
        this.height = height;
        return this;
    }

    public int getX() {
        return x;
    }

    public BuddyGuiButton setX(int x) {
        this.x = x;
        return this;
    }

    public int getY() {
        return y;
    }

    public BuddyGuiButton setY(int y) {
        this.y = y;
        return this;
    }

    public int getWidth() {
        return width;
    }

    public BuddyGuiButton setWidth(int width) {
        this.width = width;
        return this;
    }

    public int getHeight() {
        return height;
    }

    public BuddyGuiButton setHeight(int height) {
        this.height = height;
        return this;
    }

    public boolean isMouseOver(double mouseX, double mouseY) {
        return mouseX >= x && mouseX < x + this.width && mouseY >= y && mouseY < y + this.height;
    }

    public boolean isActive() {
        return active;
    }

    public void updateActiveState() {
        this.active = activeCondition == null || activeCondition.getAsBoolean();
    }

    @FunctionalInterface
    public interface ButtonNameSupplier {
        String name(@NotNull Buddy buddy);
    }

}
